@@ -9,10 +9,14 @@ import os
 
 from .hooks import GetRedisClient
 
+stub = os.environ.get('REDIS_KEY', 'REDIS')
+REDIS_DB = '{0}_DB'.format(stub)
+REDIS_URL = '{0}_URL'.format(stub)
+REDIS_MAX_CONNECTIONS = '{0}_MAX_CONNECTIONS'.format(stub)
 DEFAULT_SETTINGS = {
-    'db': os.environ.get('REDIS_DB', 0),
-    'url': os.environ.get('REDIS_URL', 'redis://localhost:6379'),
-    'max_connections': os.environ.get('REDIS_MAX_CONNECTIONS', None),
+    'db': os.environ.get(REDIS_DB, 0),
+    'url': os.environ.get(REDIS_URL, 'redis://localhost:6379'),
+    'max_connections': os.environ.get(REDIS_MAX_CONNECTIONS, None),
 }
 
 class IncludeMe(object):
